

/* This is the structure for a file.  Each file has a name, size, date,
   and description.  These are all stored as strings for easy display.*/

struct FileInfo {
  char fname[80];
  char fsize[10];
  char date[10];
  char * description;
  char read_only;
  char * wildcard;
  int area;
};


/* This is the structure that holds the commands for each archiver and the
   type of archiving that they do.
*/

struct archiver {
  char add[80];
  char extract[80];
  char view[80];
  char verify[80];
};


/* This is the structure for a file area.  A file area has an area name,
   a description (FileInfo), a location for downloading, a location
   for uploading, optionally a location for the file list, and a flag to
   determine if it has been backed up which means FBP should be run on
   the area */

struct FileArea {
  char Area[40];
  char FileInfo[80];
  char Download[80];
  char Upload[80];
  char FileList[80];
  char backed_up;
};

typedef struct {
   CHAR   fileinfo[70];       /* File area description */
   SHORT  file_num;           /* File area number */
   CHAR   uppath[40];         /* Upload path */
   CHAR   filepath[40];       /* Download path */
   CHAR   filesbbs[50];       /* CD-ROM list file name */
   CHAR   filler2[55];        /* skip the bullshit */
   CHAR   short_name[13];     /* Area's short name */
   CHAR   filler4[370];       /* fill out struct */
} LORASYS, *PLORASYS;




/* The window structure is the heart of the whole program.  A window contains
   most of the necessary information for most operations.  It has a handle for
   window operations, the depth & width of the window, flags to determine (1)if
   file descriptions should be wrapped (2) display the date, and (3) display
   the file size.  It has a variable top_display which is the number of the
   first file displayed in the window and bottom_display which is the last
   file completely displayed in the window.  It has the number of files for
   that window area, a flag which states that everything that can be displayed
   is displayed.  It has a variable to show which file is highlighted, a
   pointer to which files have been selected (this is dynamically allocated and
   is kept sorted), a counter of the number selected and a pointer to the file
   list which is also dynamically allocated.  The array FileStart simply
   keeps track of on which line, the display of each file starts.  Num_free
   keeps track of the number of free memory slots in FileInfo (this is for
   adopting files).
*/

struct Window {
  wm_handle Handle;
  int width;
  int depth;
  char changed;
  char wrap;
  char date;
  char size;
  int area;
  int top_display;
  int bottom_display;
  int numfiles;
  char all_displayed;
  int highlight;
  char dirsize[20];
  int * selected;
  int numselected;
  struct FileInfo * Files;
  char FileStart[120];
  char num_free;
  char lock;
  char SortLock;
};



struct threadinfo {
  int Win_num;
  char path [100];
  char namelist[1000][80];
  int numfiles;
  struct Window * WIN;
  int new_type;
  char newextension[5];
};



typedef struct {
    CHAR n[41];                         /* area tag or short name */
    CHAR filepath[CCHMAXPATH+1];        /* path to files */
    CHAR filesbbs[CCHMAXPATH+1];        /* files.bbs filespec */
    CHAR fileinfo[80];                  /* area description */
} GENAREAS, *PGENAREAS;



#pragma pack(1)

typedef struct {
    BYTE  fi_len;           /* the *_len members are for use in converting */
                            /* the PASCAL style strings to C style strings */
    CHAR  fileinfo[60];     /* file area description */
    BYTE  fp_len;
    CHAR  filepath[79];     /* download path I assume, info wasn't clear */
    SHORT security;
    BYTE  flags[4];
    SHORT pfilesec;
    BYTE  pflags[4];
    BYTE  attrib;
    BYTE  age;
    BYTE  fb_len;
    CHAR  filesbbs[67];     /* FILES.BBS path unless it starts with '*' */
                            /* then it refers to the upload path */
    SHORT reqbpsrate;
    CHAR  extraspace[28];

} SBBSINFO, *PSBBSINFO;
#pragma pack(4)



/*
   The following is the structure of the d_date portion of the structure
   dirent (found in sys/dirent.h).
*/


struct d_date {
  unsigned short day : 5;
  unsigned short month : 4;
  unsigned short year : 7;
} ;
